<template>
  <section
    :id="`newsStory${selectedTitles.id}`"
    :class="{ done: articleDone }">
    <h3 style="width: 70%;"> {{ selectedTitles.article_title }}</h3>

    <div class="edit-story">
      <a @click.prevent="showQuestions = !showQuestions" class="button">EDIT STORY</a>
    </div>
    <div v-show="showQuestions">
      <div v-if="selectedTitles.article_title.includes('Submitted')">
        <div v-if="storyIdeas.length">
          <p style="padding-top: 1rem;">Here are the submitted stories from the Kiosk. Type one of these stories below.</p>
          <div id="submitted-stories">
            <div class="submitted-story"
              v-for="storyIdea in storyIdeas"
              :key="storyIdea.id">
              <div class="submitted-story-section">
                <h4>Headline</h4>
                <p>{{ storyIdea.headline }}</p>
              </div>
              <div class="submitted-story-section">
                <h4>Article Idea</h4>
                <p>{{ storyIdea.story }}</p>
              </div>
              <div class="submitted-story-section">
                <h4>Submitted By</h4>
                <p>{{ storyIdea.submitter }}</p>
              </div>
            </div>
          </div>
        </div>
        <div v-else>
          <p style="padding-top: 1rem;">There are no submitted stories from the Kiosk yet. Check back later.</p>
        </div>
      </div>
      <form>
        <div
          v-for="(question, index) in selectedQuestions"
          :key="question.id">
          <label>{{ question.title }}</label>
          <input
            v-if="question.html_tag === 'input'"
            :maxlength="question.max_char_length"
            :id="question.style_id"
            v-model="selectedAnswers[`${index}`].answer"
            type="text">
          <textarea
            v-if="question.html_tag === 'textarea'"
            :name="question.id"
            :id="question.style_id"
            :maxlength="question.max_char_length"
            v-model="selectedAnswers[`${index}`].answer"
            :class="[`${question.style_class}`]" />
          <div
            :id="[question.style_id] + '-select'"
            v-if="question.html_tag === 'img'"
            style="padding-bottom: 3rem; padding-top: 3rem;"
            class="choose">
            <a
              @click="$refs.newspaperPhotos.Open(index)"
              class="button choose-image">CHOOSE IMAGE
            </a>
            <img v-show="selectedAnswers[`${index}`].answer" style="margin-top: 3rem; width: 200px; height: 200px;" :src="selectedAnswers[`${index}`].answer">
          </div>
          <label
            v-if="question.html_tag !== 'img'"
            class="sublabel">Maximum length is {{ question.max_char_length }} characters.</label>
        </div>
      </form>
      <div class="save">
        <a
          style="display: block; margin: auto; width: 17%; margin-top: 3rem;"
          @click="putStory()"
          type="submit"
          class="button submit">SAVE STORY
        </a>
      </div>
    </div>
    <shop-modal
      @selected-image="imageSelected = true"
      @saved-image="savedImage"
      ref="newspaperPhotos">
      <div
        slot="newspaper-photos"
        id="overlay">
        <div id="image-gallery-popup" data-control="Popup" class="modalwindow" style="margin-top: 0px; display: block;">
          <div class="windowcontent">
            <h1>Select Image</h1>
            <div id="image-gallery-images">
              <p>No images available at this time.</p>
              <template v-for="image in images">
              <div
              class="image"
              :key="image.id">
                <img
                  :key="image.id"
                  :class="{selected: image.selected}"
                  @click="$refs.newspaperPhotos.toggleSelectedStyle(image, images)"
                  :src="image.stub" >
              </div>
              </template>
            </div>
            <div class="gradient"></div>
            <div class="choose-image">
              <a
                v-show="imageSelected"
                @click="$refs.newspaperPhotos.saveImgSrc()"
                class="button choose">Choose Image</a>
            </div>
          </div>
          <a @click="$refs.newspaperPhotos.Close()" class="closebutton">
            <img src="/images/closebutton.png">
          </a>
        </div>
      </div>
    </shop-modal>
  </section>
</template>

<script>
import ShopModal from '../../../../../shared/views/ShopModal.vue';
export default {
  components: {
    ShopModal
  },
  props: {
    selectedTitles: Object,
    selectedQuestions: Array,
    selectedAnswers: Array,
    storyIdeas: Array,
  },
  data() {
    return {
      showQuestions: false,
      images: [],
      imageSelected: false,
      intervalID: ''
    }
  },
  mounted:function(){
    this.getUploadRefs();
    // perhaps this is silly, but incase one person is uploading a bunch of images and another is editing stories, they will get near fresh images by polling this endpoint
    this.intervalID = setInterval(() => {
      this.getUploadRefs();
    }, 10000);
  },
  destroyed: function() {
    clearInterval(this.intervalID);
  },
  methods: {
    savedImage(obj) {
      this.selectedAnswers[`${obj.id}`].answer = obj.src;
    },
    putStory() {
      this.showQuestions = !this.showQuestions;
      this.$emit('put-story', { selectedAnswers: this.selectedAnswers });
    },
    getUploadRefs(){
      app.api.Get("images?type=newspaper").then( Response => {
        this.images = Response;
      })
      .catch( x => app.Message( x.error, "error" ));
    }
  },
  computed: {
    articleDone: function() {
      const filteredAnswers = this.selectedAnswers.filter(answer => answer.answer !== '');
      if (filteredAnswers.length === this.selectedAnswers.length) {
        return true;
      } else {
        return false;
      }
    }
  }
}
</script>

<style>

</style>